function [Gmat,Evals,Mcut,Ecut,Lcut] = getGmatmj(K,ORDE,ORDL,MMAX,ORDM,almj,blmj,usecontfrac)
% get the matrix of Fourier-laplace transformed G coefficients for
% different m, j, values for a particular K
% if usecontfrac is set to 1, use continued fractions
% otherwise use matrix inversion
% indices of Gmat (in order) are: lambda, l,j,m
% where l is actually how far above the max(m,j) value the l index is
% ORDE is number of eigenvalues
% ORDL is the maximal order in L above a given m value
% MMAX is the maximal m, j values 
% ORDM is how big a matrix to use for the inversion

% minimal N value to use in checking where to cut off
Ncheck = 0.5; 
cutM = 1e-10;
cutE = 1e-10;
cutL = 1e-12;
Mcut = MMAX+1;
Ecut = ORDE*ones(MMAX+1,MMAX+1);
Lcut = ORDL*ones(ORDE,MMAX+1,MMAX+1);

if (nargin <8)
    usecontfrac=0;
end

Evals = -Inf*ones(ORDE,MMAX+1,MMAX+1);
Gmat = zeros(ORDE,ORDL+1,MMAX+1,MMAX+1);

Mdone = 0;
for m = 0:MMAX
    mi = m+1;
    for j = [m,0:m-1,m+1:MMAX]
        ji = j+1;
        
        mh = max(m,abs(j));
        
        % set up the matrix
        Amat = zeros(ORDM+1,ORDM+1);
        for l = 0:ORDM
            if mh+l==0
                Amat(l+1,l+1) = (mh+l)*(mh+l+1);
            else
                Amat(l+1,l+1) = (mh+l)*(mh+l+1)-i*K*blmj(l+1,ji,mi);
            end
            if (l<ORDM)
                Amat(l+1,l+2) = -i*K*almj(l+2,ji,mi);
            end
            if (l>0)
                Amat(l+1,l) = -i*K*almj(l+1,ji,mi);
            end
        end
        
        % get the eigenvalues
        evals = eig(-Amat);
        [tmp1,tmp2] = sort(real(evals),'descend');
        evals = evals(tmp2);
        Evals(:,ji,mi) = evals(1:ORDE);                
        
        % check if we've reached end of m index
        if (j==m) 
            check = K^2*exp(real(Evals(1,ji,mi))*Ncheck);
            if abs(check) < cutM
                %[m j Evals(1,ji,mi)]
                Mdone = 1; 
                Gmat(:,:,ji,mi) = 0;
                break
            end
        end
        
        % get the G coefficients
        % note: the l index is how far l is above max(m,j) 
        if (usecontfrac) 
            % use continued fractions 
            for ec = 1:ORDE
                Gmat(ec,:,ji,mi) = 0;
                p = Evals(ec,ji,mi);
                Lcut(ec,ji,mi) = ORDL;
                dpJ = getdpJforcePoles(p,K,m,j,ORDL,ORDM,almj,blmj);
                Gmat(ec,:,ji,mi) = 1./dpJ;
                checklist= real(Gmat(ec,:,ji,mi))*K^2*exp(real(Evals(ec,ji,mi)*Ncheck));
                cutind = find(abs(real(checklist))<cutL);
                if (length(cutind)>0)
                    Lcut(ec,ji,mi) = cutind(1)-1;
                    Gmat(ec,cutind(1):end,ji,mi) = 0;
                else
                    Lcut(ec,ji,mi) = ORDL;
                end
                
                % check if have gone far enough in eigenvalues                
                if (max(abs(checklist(1:Lcut(ec,ji,mi)+1))) < cutE)
                    Ecut(ji,mi) = ec;
                    break
                end
            end
        else
            % use matrix inversion        
            for ec = 1:ORDE                                
                Gmat(ec,:,ji,mi) = 0;
                p = Evals(ec,ji,mi);
                eprod = (prod(p-evals(1:ec-1))*prod(p-evals(ec+1:end)));
                checklist = zeros(ORDL+1,1);
                for l = 0:ORDL                    
                    p = Evals(ec,ji,mi);
                    cA = cofactor(p*eye(ORDM+1)+Amat,l+1,l+1);               
                    Gmat(ec,l+1,ji,mi) = cA/eprod;
                    % check if have gone far enough in L values
                    checklist(l+1) = real(Gmat(ec,l+1,ji,mi))*K^2*exp(real(Evals(ec,ji,mi)*Ncheck));
                    if (abs(checklist(l+1))< cutL)  
                        Lcut(ec,ji,mi) = l;
                        break
                    end
                end
                
                % check if have gone far enough in eigenvalues                
                if (max(abs(checklist)) < cutE)
                    Ecut(ji,mi) = ec;
                    break
                end
            end
        end        
            
    end
    if (Mdone)
        Mcut = m;
        break
    end
end

end