function Jfact = getJfact(Nlist,T,eta,klist,Gdata,Evals,Mcuts,Ecuts)
% get the J factor for different dimensionless chain lengths 
% Nlist is a row vector of chain lengths
% Gdata, Mcuts are obtained from getGDataForJfact.m (or loaded from saved
% file)
% T is dimensionless twist
% eta = lp/lt - 1 (where lp=bend persistence length, lt =twist persistence)

nk = length(klist);

% get the Fourier-transformed G(K,N)
nn = length(Nlist);
Gvals = zeros(nk,nn);

MMAX = max(Mcuts);
CTJN = zeros(MMAX+1,nn); EJN = CTJN;
for j = 0:MMAX
    CTJN(j+1,:) = cos(T*j*Nlist);
    EJN(j+1,:) = exp(-eta*j^2*Nlist);
end

for kc = 1:nk    
    for m = 0:Mcuts(kc)-1
        for j = 0:Mcuts(kc)-1
            emax = Ecuts(j+1,m+1,kc);
            tmp = transpose(Gdata(1:emax,j+1,m+1,kc))*exp(Evals(1:emax,j+1,m+1,kc)*Nlist);
            
            if (m==0 & j==0)
                Gvals(kc,:) = Gvals(kc,:) + tmp;
            elseif (m==0 || j==0)
                Gvals(kc,:) = Gvals(kc,:) + 2*EJN(j+1,:).*(real(tmp).*CTJN(j+1,:));
            else
                Gvals(kc,:) = Gvals(kc,:) + 4*EJN(j+1,:).*(real(tmp).*CTJN(j+1,:));
            end
        end
    end
    
end

% integrate over K to get the J factor
dk = diff(klist');
Jfact = zeros(nn,1);
for nc = 1:nn
    vals = Gvals(:,nc).*klist'.^2;
    Jfact(nc) = sum((vals(1:end-1)+vals(2:end))/2.*dk(1:end));
end
Jfact = real(Jfact)/(2*pi^2);

end
