% --------------
%% use this script to get started with calculating J factors

%% ---------------
% first get the matrix of G coefficient data
% This takes a long time to run, but only needs to be done once when
% you first begin using this code
% once you've generated the large data file (should take up ~50MB)
% then as long as you don't need smaller N or greater accuracy, 
% the data in this file can be used for all subsequent calculations


% The parameters below should be sufficient to give
% J-factor values for dimensionless N >0.5
% up to an accuracy of about 1e-6

% maximum number of eigenvalues
ORDE = 10;
% maximum L index (above the m,j indices)
ORDL = 20;
% maximum m,j indices
MMAX = 8;
% size of matrix to use for calculating eigenvalues
ORDM = 30;
% list of wavevector magnitudes k
klist = logspace(-2,log10(5500),5000);

tic
[Gdata,Evals,Mcuts,Ecuts] = getGDataForJFact(klist,ORDE,ORDL,MMAX,ORDM);
toc
save('JfactData.mat','Gdata','Evals','Mcuts','Ecuts','klist','ORDE','MMAX')

% for subsequent calculations, retrieve this data via
% load('JfactData.mat')

%% ------------------------
% now use the data matrix calculated above (or extracted from file)
% to get the J values of interest

% the example parameters below reproduce 
% Fig. 2 in Spakowitz, 2006 "Wormlike Chain Statistics with Twist and Fixed Ends"

% dimensionless twist density (tau*2*lp)
T = 5*pi;
% eta=lp/lt - 1 where lp is the bend and lt is the twist persistence lengths
eta = 0;

% list of dimensionless chain lengths (L/(2*lp))
% This must be a row vector
% The calculations are vectorized in N (they work faster for a 
% list of N values than with a for loop and individual N values)
Nlist = linspace(0.5,4,100);

% get J factor values
Jfact = getJfact(Nlist,T,eta,klist,Gdata,Evals,Mcuts,Ecuts);

% plot results
plot(Nlist,Jfact)
ylim([0,0.05])
